@@ -98,21 +98,22 @@ def build_hugo_head(notion):
 
 
 def update_page(notion_client, notion) -> bool:
-    return notion_client.pages.update(notion.page_id, properties={
-        "Slug": {
-            "rich_text": [
-                {
-                    "type": "text",
-                    "text": {
-                        "content": notion.slug
+    if notion.update:
+        return notion_client.pages.update(notion.page_id, properties={
+            "Slug": {
+                "rich_text": [
+                    {
+                        "type": "text",
+                        "text": {
+                            "content": notion.slug
+                        }
                     }
-                }
-            ]
-        },
-        "Url": {
-            "url": "https://blog.gclmit.club/post/{}/".format(notion.slug)
-        },
-    })
+                ]
+            },
+            "Url": {
+                "url": "https://blog.gclmit.club/post/{}/".format(notion.slug)
+            },
+        })
 
 
 def get_page_list(notion_client, database_id):
@@ -160,8 +161,15 @@ def generate_slug():
     return str(worker.get_id())
 
 
+def is_page_update(data):
+    if slug(data) in '':
+        return True
+    return False
+
+
 class NotionPage:
     def __init__(self, data, token):
+        self.update = is_page_update(data)
         self.token = token
         self.page_id = get_page_id(data)
         self.title = title(data)
